.. only: not latex

    .. image:: pybind11-logo.png

pybind11 --- Seamless operability between C++11 and Python
==========================================================

.. only: not latex

    Contents:

.. toctree::
   :maxdepth: 1

   intro
   changelog
   upgrade

.. toctree::
   :caption: The Basics
   :maxdepth: 2

   basics
   classes
   compiling

.. toctree::
   :caption: Advanced Topics
   :maxdepth: 2

   advanced/functions
   advanced/classes
   advanced/exceptions
   advanced/smart_ptrs
   advanced/cast/index
   advanced/pycpp/index
   advanced/embedding
   advanced/misc

.. toctree::
   :caption: Extra Information
   :maxdepth: 1

   faq
   benchmark
   limitations
   reference
